@@ -3,11 +3,11 @@
 }
 
 StartWelcomeMessage <- function(){
-  paste(c("==============================\n",
+  paste(c("=====================================================\n",
           "MAPpoly Package",
           " [Version ", utils::packageDescription("mappoly")$Version,
            utils::packageDescription("mappoly")$Date, "]\n",
           "More information: https://github.com/mmollina/MAPpoly\n",
-          "=============================="),
-        sep="")
+          "====================================================="),
+        sep = "")
 }
